package
Version:
v0.4.0
Opens a new window with list of versions in this module.
Published: Jun 2, 2026
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
validx 包 Package
validx 提供前置条件、不变量和非空字符串检查助手。
Validation failures return classified errx errors while keeping validation free of external dependencies.
Documentation
¶
Package validx 提供前置条件和不变量错误助手。
package main
import (
"github.com/ZoneCNH/kernel/validx"
)
func main() {
_ = validx.RequireNonEmpty("value", "name")
}
Output:
Source Files
¶
Click to show internal directories.
Click to hide internal directories.